@@ -1,4 +1,5 @@
 from django import forms
+from django.contrib.auth.models import User
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.admin.models import LogEntry, ADDITION, CHANGE
 from django.contrib.admin.views.decorators import staff_member_required
@@ -143,6 +144,10 @@ def match_columns(request, import_log_id):
         for import_method in model_class.simple_import_methods:
             field_choices += (("simple_import_method__{0}".format(import_method),
                                "{0} (Method)".format(import_method)),)
+    # User model should allow set password
+    if model_class == User:
+        field_choices += (("simple_import_method__{0}".format('set_password'),
+                               "Set Password (Method)"),) 
     
     i = 0
     for form in formset:
@@ -246,8 +251,7 @@ def set_field_from_cell(import_log, new_object, header_row_field_name, cell):
     elif header_row_field_name.startswith('simple_import_custom__'):
         new_object.set_custom_value(header_row_field_name[22:], cell)
     elif header_row_field_name.startswith('simple_import_method__'):
-        if header_row_field_name[22:] in new_object.simple_import_methods:
-            getattr(new_object, header_row_field_name[22:])(cell)
+        getattr(new_object, header_row_field_name[22:])(cell)
        
 
 @staff_member_required
